# Tham chiếu CLI

## Các lệnh chính

- `vyro run --app <module:attr>`
- `vyro dev --app <module:attr>`
- `vyro doctor [--strict]`
- `vyro openapi ...`
- `vyro compat ...`
- `vyro release ...`

## Exit codes

- `0`: thành công
- `1`: lỗi thực thi/tooling/runtime
- `2`: lỗi validation/usage
